==> apache-seatunnel-2.3.3-src.tar.gz: apache-seatunnel-2.3.3-src/seatunnel-connectors-v2/connector-google-firestore/src/main/java/org/apache/seatunnel/connectors/seatunnel/google/firestore/config/FirestoreParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.google.firestore.config;

import org.apache.seatunnel.shade.com.typesafe.config.Config;

import lombok.Data;

import java.io.Serializable;

@Data
public class FirestoreParameters implements Serializable {

    private String projectId;

    private String credentials;

    private String collection;

    public FirestoreParameters buildWithConfig(Config config) {
        this.projectId = config.getString(FirestoreConfig.PROJECT_ID.key());
        this.collection = config.getString(FirestoreConfig.COLLECTION.key());
        if (config.hasPath(FirestoreConfig.CREDENTIALS.key())) {
            this.credentials = config.getString(FirestoreConfig.CREDENTIALS.key());
        }
        return this;
    }
}

==> apache-seatunnel-2.3.10-src.tar.gz: apache-seatunnel-2.3.10-src/seatunnel-connectors-v2/connector-google-firestore/src/main/java/org/apache/seatunnel/connectors/seatunnel/google/firestore/config/FirestoreParameters.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.seatunnel.connectors.seatunnel.google.firestore.config;

import org.apache.seatunnel.api.configuration.ReadonlyConfig;

import lombok.Data;

import java.io.Serializable;

@Data
public class FirestoreParameters implements Serializable {

    private String projectId;

    private String credentials;

    private String collection;

    public FirestoreParameters buildWithConfig(ReadonlyConfig config) {
        this.projectId = config.get(FirestoreSinkOptions.PROJECT_ID);
        this.collection = config.get(FirestoreSinkOptions.COLLECTION);
        if (config.getOptional(FirestoreSinkOptions.CREDENTIALS).isPresent()) {
            this.credentials = config.get(FirestoreSinkOptions.CREDENTIALS);
        }
        return this;
    }
}
